@@ -10,4 +10,6 @@
     ("set0" . 8709) ;; ∅ U+2205
     ("`<`" . 8842) ;; ⊊ U+228A
     ("`<=`" . 8838) ;; ⊆ U+2286
+    ("^\\+" . ?⁺) ;; ⁺ U+207A
+    ("^\\-" . ?⁻) ;; ⁻ U+207B
 ))))
